import { registerBlockType } from '@wordpress/blocks';
import {
    InspectorControls,
    useBlockProps,
} from '@wordpress/block-editor';
import { TextControl } from '@wordpress/components';

import icons from './icons';


registerBlockType('planist-gutenberg/planist-block', {
    title: 'Planist',
    icon: icons.planist,
    category: 'widgets',
    keyword: ['planist', 'event', 'schedule', 'calender'],
    attributes: {
        username: {
            type: 'string',
            default: ''
        },
        duration: {
            type: 'string',
            default: '30m'
        }
    },
    example: {
        attributes: {
            username: 'mohsen',
            duration: '45m',
        },
    },
    edit: (props) => {
        const {
            className,
            attributes: {
                username,
                duration
            },
            setAttributes,
        } = props;

        const onChangeUsername = (value) => {
            setAttributes({ username: value });
        };

        const onChangeDuration = (value) => {
            setAttributes({ duration: value });
        };

        return (
            <div {...useBlockProps()}>
                <InspectorControls key="setting">
                    <div className={className} style={{ padding: '10px' }}>
                        <TextControl
                            label="Username"
                            value={username}
                            onChange={onChangeUsername}
                        />
                        <TextControl
                            label="Duration"
                            value={duration}
                            onChange={onChangeDuration}
                        />
                    </div>
                </InspectorControls>

                <div className="planist-block">
                    {username ? (<div>{icons.planist}/{username}{duration ? '/' + duration : ''}</div>) : (<div>{icons.planist} Set username and duration</div>)}
                </div>
            </div>
        );
    },
    save: (props) => {
        const {
            className,
            attributes: {
                username,
                duration
            },
        } = props;

        return `[planist username="${username}" duration="${duration}"]`;
    },
});
